#!/bin/bash

# This script is used twice: first to align the reads to the genome
# and, after PrInSeS runs, to re-align the reads to the PrInSeS genome in order to validate them.
# It takes the genome fasta file as an argument
# If the file is "genome.fa" it must produce a "genome.fa.bam" sorted, indexed alignment file

# Change the following if "bwa" and "samtools" are not in your default path:
BWA=bwa
SAMTOOLS=samtools

GENOME=$1
if [ "$GENOME" == "" ]; then
	echo Usage: $0 genome.fa
	exit 1
fi

READS=reads.fastq

LOGFILE=$GENOME.alignment.log

$BWA index $GENOME >> $LOGFILE 2>&1
$BWA aln $GENOME $READS > $GENOME.sai 2>>$LOGFILE
$BWA samse $GENOME $GENOME.sai $READS > $GENOME.sam 2>>$LOGFILE
$SAMTOOLS view -bt $GENOME.fa.fai -o $GENOME.unsorted.bam $GENOME.sam >> $LOGFILE 2>&1
$SAMTOOLS sort $GENOME.unsorted.bam $GENOME >> $LOGFILE 2>&1
$SAMTOOLS index $GENOME.bam >> $LOGFILE 2>&1
