#!/bin/bash

OUTDIRECTORY=prinsesdir
PRINSES=../prinses

GENOME=phix.fa

LOGFILE=prinses.log

./align.sh phix.fa

# Create the "PrInSeS reads file"
$PRINSES prepare $GENOME.bam > reads.prinses 2> $LOGFILE

# Run prinses to generate a file with variants and two sequence files in 
$PRINSES assemble -maxThreads 1 -verbose $GENOME $GENOME.bam reads.prinses $OUTDIRECTORY >> $LOGFILE 2>&1

# Run tool to validate each variant by re-aligning
# Note this step may take the most time and it will certainly use the most disk space.
# It's also not strictly necessary, but it will reduce false positives.
# It creates a file named "variants.verified.txt".
$PRINSES validate $OUTDIRECTORY $GENOME $GENOME.bam ./align.sh >> $LOGFILE 2>&1

# Run tool to create the final "consensus" list of variants:
../prinsesConsensus.pl $OUTDIRECTORY/variants.verified.txt > $OUTDIRECTORY/variants.consensus.txt 2>> $LOGFILE

# Finally apply the validated variants to create the PrInSeS version of the genome:
$PRINSES apply $OUTDIRECTORY/alignmentConsensus.fa $OUTDIRECTORY/variants.consensus.txt > $OUTDIRECTORY/phix.prinses.fa 2>> $LOGFILE
